# from fastapi import FastAPI
# from fastapi.openapi.docs import (
#     get_redoc_html,
#     get_swagger_ui_html,
#     get_swagger_ui_oauth2_redirect_html,
# )
# from fastapi.staticfiles import StaticFiles
#
#  todo 增加离线环境的openapi文件注册
# def offline_swagger(app: FastAPI):
#     """
#     离线环境下使用swagger,需要的静态文件可以执行 fast-tmp staticfile
#     """
#     assert app.redoc_url is None
#     assert app.docs_url is None
#     app.mount("/static", StaticFiles(directory="static"), name="static")
#
#     @app.get("/docs", include_in_schema=False)
#     async def custom_swagger_ui_html():
#         return get_swagger_ui_html(
#             openapi_url=app.openapi_url,
#             title=app.title + " - Swagger UI",
#             oauth2_redirect_url=app.swagger_ui_oauth2_redirect_url,
#             swagger_js_url="/static/swagger-ui-bundle.js",
#             swagger_css_url="/static/swagger-ui.css",
#         )
#
#     @app.get(app.swagger_ui_oauth2_redirect_url, include_in_schema=False)
#     async def swagger_ui_redirect():
#         return get_swagger_ui_oauth2_redirect_html()
#
#     @app.get("/redoc", include_in_schema=False)
#     async def redoc_html():
#         return get_redoc_html(
#             openapi_url=app.openapi_url,
#             title=app.title + " - ReDoc",
#             redoc_js_url="/static/redoc.standalone.js",
#         )
